@@ -1,8 +1,8 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
-""" A few useful function/method decorators."""
+"""A few useful function/method decorators."""
 
 from __future__ import annotations
 
@@ -10,14 +10,13 @@ import functools
 import inspect
 import sys
 import warnings
-from collections.abc import Callable
+from collections.abc import Callable, Generator
 from typing import TypeVar
 
-import wrapt
-
 from astroid import util
 from astroid.context import InferenceContext
 from astroid.exceptions import InferenceError
+from astroid.typing import InferenceResult
 
 if sys.version_info >= (3, 10):
     from typing import ParamSpec
@@ -28,76 +27,18 @@ _R = TypeVar("_R")
 _P = ParamSpec("_P")
 
 
-@wrapt.decorator
-def cached(func, instance, args, kwargs):
-    """Simple decorator to cache result of method calls without args."""
-    cache = getattr(instance, "__cache", None)
-    if cache is None:
-        instance.__cache = cache = {}
-    try:
-        return cache[func]
-    except KeyError:
-        cache[func] = result = func(*args, **kwargs)
-        return result
-
-
-# TODO: Remove when support for 3.7 is dropped
-# TODO: astroid 3.0 -> move class behind sys.version_info < (3, 8) guard
-class cachedproperty:
-    """Provides a cached property equivalent to the stacking of
-    @cached and @property, but more efficient.
-
-    After first usage, the <property_name> becomes part of the object's
-    __dict__. Doing:
-
-      del obj.<property_name> empties the cache.
-
-    Idea taken from the pyramid_ framework and the mercurial_ project.
-
-    .. _pyramid: http://pypi.python.org/pypi/pyramid
-    .. _mercurial: http://pypi.python.org/pypi/Mercurial
-    """
-
-    __slots__ = ("wrapped",)
-
-    def __init__(self, wrapped):
-        if sys.version_info >= (3, 8):
-            warnings.warn(
-                "cachedproperty has been deprecated and will be removed in astroid 3.0 for Python 3.8+. "
-                "Use functools.cached_property instead.",
-                DeprecationWarning,
-            )
-        try:
-            wrapped.__name__
-        except AttributeError as exc:
-            raise TypeError(f"{wrapped} must have a __name__ attribute") from exc
-        self.wrapped = wrapped
-
-    @property
-    def __doc__(self):
-        doc = getattr(self.wrapped, "__doc__", None)
-        return "<wrapped by the cachedproperty decorator>%s" % (
-            "\n%s" % doc if doc else ""
-        )
-
-    def __get__(self, inst, objtype=None):
-        if inst is None:
-            return self
-        val = self.wrapped(inst)
-        setattr(inst, self.wrapped.__name__, val)
-        return val
-
-
 def path_wrapper(func):
-    """return the given infer function wrapped to handle the path
+    """Return the given infer function wrapped to handle the path.
 
     Used to stop inference if the node has already been looked
     at for a given `InferenceContext` to prevent infinite recursion
     """
 
     @functools.wraps(func)
-    def wrapped(node, context=None, _func=func, **kwargs):
-        """wrapper function handling context"""
+    def wrapped(
+        node, context: InferenceContext | None = None, _func=func, **kwargs
+    ) -> Generator:
+        """Wrapper function handling context."""
         if context is None:
             context = InferenceContext()
         if context.push(node):
@@ -118,45 +59,52 @@ def path_wrapper(func):
     return wrapped
 
 
-@wrapt.decorator
-def yes_if_nothing_inferred(func, instance, args, kwargs):
-    generator = func(*args, **kwargs)
+def yes_if_nothing_inferred(
+    func: Callable[_P, Generator[InferenceResult]]
+) -> Callable[_P, Generator[InferenceResult]]:
+    def inner(*args: _P.args, **kwargs: _P.kwargs) -> Generator[InferenceResult]:
+        generator = func(*args, **kwargs)
 
-    try:
-        yield next(generator)
-    except StopIteration:
-        # generator is empty
-        yield util.Uninferable
-        return
+        try:
+            yield next(generator)
+        except StopIteration:
+            # generator is empty
+            yield util.Uninferable
+            return
 
-    yield from generator
+        yield from generator
+
+    return inner
 
 
-@wrapt.decorator
-def raise_if_nothing_inferred(func, instance, args, kwargs):
-    generator = func(*args, **kwargs)
-    try:
-        yield next(generator)
-    except StopIteration as error:
-        # generator is empty
-        if error.args:
-            # pylint: disable=not-a-mapping
-            raise InferenceError(**error.args[0]) from error
-        raise InferenceError(
-            "StopIteration raised without any error information."
-        ) from error
-    except RecursionError as error:
-        raise InferenceError(
-            f"RecursionError raised with limit {sys.getrecursionlimit()}."
-        ) from error
+def raise_if_nothing_inferred(
+    func: Callable[_P, Generator[InferenceResult]],
+) -> Callable[_P, Generator[InferenceResult]]:
+    def inner(*args: _P.args, **kwargs: _P.kwargs) -> Generator[InferenceResult]:
+        generator = func(*args, **kwargs)
+        try:
+            yield next(generator)
+        except StopIteration as error:
+            # generator is empty
+            if error.args:
+                raise InferenceError(**error.args[0]) from error
+            raise InferenceError(
+                "StopIteration raised without any error information."
+            ) from error
+        except RecursionError as error:
+            raise InferenceError(
+                f"RecursionError raised with limit {sys.getrecursionlimit()}."
+            ) from error
 
-    yield from generator
+        yield from generator
+
+    return inner
 
 
 # Expensive decorators only used to emit Deprecation warnings.
 # If no other than the default DeprecationWarning are enabled,
 # fall back to passthrough implementations.
-if util.check_warnings_filter():
+if util.check_warnings_filter():  # noqa: C901
 
     def deprecate_default_argument_values(
         astroid_version: str = "3.0", **arguments: str
@@ -186,7 +134,7 @@ if util.check_warnings_filter():
                     try:
                         index = keys.index(arg)
                     except ValueError:
-                        raise Exception(
+                        raise ValueError(
                             f"Can't find argument '{arg}' for '{args[0].__class__.__qualname__}'"
                         ) from None
                     if (
@@ -207,9 +155,11 @@ if util.check_warnings_filter():
                     ):
                         warnings.warn(
                             f"'{arg}' will be a required argument for "
-                            f"'{args[0].__class__.__qualname__}.{func.__name__}' in astroid {astroid_version} "
+                            f"'{args[0].__class__.__qualname__}.{func.__name__}'"
+                            f" in astroid {astroid_version} "
                             f"('{arg}' should be of type: '{type_annotation}')",
                             DeprecationWarning,
+                            stacklevel=2,
                         )
                 return func(*args, **kwargs)
 
@@ -233,13 +183,12 @@ if util.check_warnings_filter():
         def deco(func: Callable[_P, _R]) -> Callable[_P, _R]:
             @functools.wraps(func)
             def wrapper(*args: _P.args, **kwargs: _P.kwargs) -> _R:
-
                 keys = list(inspect.signature(func).parameters.keys())
                 for arg, note in arguments.items():
                     try:
                         index = keys.index(arg)
                     except ValueError:
-                        raise Exception(
+                        raise ValueError(
                             f"Can't find argument '{arg}' for '{args[0].__class__.__qualname__}'"
                         ) from None
                     if arg in kwargs or len(args) > index:
@@ -248,6 +197,7 @@ if util.check_warnings_filter():
                             f"'{args[0].__class__.__qualname__}.{func.__name__}' is deprecated "
                             f"and will be removed in astroid {astroid_version} ({note})",
                             DeprecationWarning,
+                            stacklevel=2,
                         )
                 return func(*args, **kwargs)
 
@@ -260,7 +210,9 @@ else:
     def deprecate_default_argument_values(
         astroid_version: str = "3.0", **arguments: str
     ) -> Callable[[Callable[_P, _R]], Callable[_P, _R]]:
-        """Passthrough decorator to improve performance if DeprecationWarnings are disabled."""
+        """Passthrough decorator to improve performance if DeprecationWarnings are
+        disabled.
+        """
 
         def deco(func: Callable[_P, _R]) -> Callable[_P, _R]:
             """Decorator function."""
@@ -271,7 +223,9 @@ else:
     def deprecate_arguments(
         astroid_version: str = "3.0", **arguments: str
     ) -> Callable[[Callable[_P, _R]], Callable[_P, _R]]:
-        """Passthrough decorator to improve performance if DeprecationWarnings are disabled."""
+        """Passthrough decorator to improve performance if DeprecationWarnings are
+        disabled.
+        """
 
         def deco(func: Callable[_P, _R]) -> Callable[_P, _R]:
             """Decorator function."""
